#[repr(C, align(8))]pub struct DirectNode<'a, V> { /* private fields */ }Expand description
direct node descriptor for memory pointer, normally a tiny memory buffer
SAFETY: node operations in immutable by unsafe code, this works because all ops for same node are expected to be ran in a single thread
Implementations
Sourceimpl<'a, V> DirectNode<'a, V>
impl<'a, V> DirectNode<'a, V>
pub fn from_slice(buf: &[u8]) -> Self
pub fn new(size: usize) -> Option<Self>
pub fn copy_from_slice(buf: &[u8]) -> Option<Self>
pub fn init(&self, flags: usize, level: usize, nchild: usize)
pub fn get_val(&self, index: usize) -> &V
pub fn set_val(&self, index: usize, val: &V)
pub fn get_userdata(&self) -> u32
pub fn set_userdata(&self, data: u32)
pub fn get_capacity(&self) -> usize
pub fn as_ref(&self) -> &[u8] ⓘ
pub fn as_mut(&self) -> &mut [u8] ⓘ